# Init Flask Restful Api

This project is no longer maintained, please visit：https://github.com/Deacone/cookiecutter-flask-rest

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rflask)
![PyPI - Downloads](https://img.shields.io/pypi/dd/rflask)
![PyPI - Format](https://img.shields.io/pypi/format/rflask)
![PyPI - License](https://img.shields.io/pypi/l/rflask)
![PyPI](https://img.shields.io/pypi/v/rflask)

## Installing

Install and update using `pip`:

```bash
pip install -U rflask
```

## Example

```bash
$ rflask init
    project_name: [flask-restful-api-20200125-090404]
    author: [Deacon]
    author_email: [deacon@example.com]
    description: [Flask restful api project.]
    ...
    ...
    Create file /Users/donghp/Downloads/Git_doc/PythonProject/init-flask-restful-api/flask-restful-api-20200125-090404/supervisord_example.conf

    Done.
```

## Project directory tree

```
.
    ├── applications
    │   ├── test
    │   │   ├── README.rst
    │   │   ├── __init__.py
    │   │   ├── models.py
    │   │   ├── urls.py
    │   │   └── views.py
    │   ├── user
    │   │   ├── README.rst
    │   │   ├── __init__.py
    │   │   ├── models.py
    │   │   └── views.py
    │   └── __init__.py
    ├── enums
    │   └── __init__.py
    ├── exceptions
    │   ├── __init__.py
    │   └── project_excepions.py
    ├── flask_ext
    │   ├── __init__.py
    │   └── logger.py
    ├── logs
    ├── requirements
    │   ├── dev.txt
    │   └── prod.txt
    ├── scripts
    │   ├── __init__.py
    │   └── commands.py
    ├── utils
    │   └── __init__.py
    ├── Dockerfile
    ├── LICENSE
    ├── Pipfile
    ├── README.md
    ├── __init__.py
    ├── app.py
    ├── autoapp.py
    ├── compat.py
    ├── database.py
    ├── docker-compose.yml
    ├── extensions.py
    ├── gunicorn.conf.py
    ├── gunicorn_example.conf.py
    ├── settings.py
    ├── setup.py
    ├── supervisord.conf
    └── supervisord_example.conf

```

Then, you can do like this:

```
$ cd your_project
$ pip install pipenv
$ pipenv install --dev
$ pipenv run python app.py
 * Serving Flask app "autoapp" (lazy loading)
 * Environment: dev
 * Debug mode: on
2020-01-23 13:03:24,151 [4554636736:MainThread] [_internal.py:_internal:_log] [INFO]:  * Running on http://127.0.0.1:5000/ (Press CTRL+C to quit)
2020-01-23 13:03:24,152 [4554636736:MainThread] [_internal.py:_internal:_log] [INFO]:  * Restarting with stat
2020-01-23 13:03:24,600 [4616764864:MainThread] [_internal.py:_internal:_log] [WARNING]:  * Debugger is active!
2020-01-23 13:03:24,604 [4616764864:MainThread] [_internal.py:_internal:_log] [INFO]:  * Debugger PIN: 186-303-110
```

## Deploy to docker

In project root direcroty, open terminal:

```
$ git clone ***.git
$ cd <your_project>
$ docker-compose up
```

## Links


* Documentation: https://github.com/Deacone/init-flask-restful-api/blob/master/README.md
* Code: https://github.com/Deacone/init-flask-restful-api
* Issue tracker: https://github.com/Deacone/init-flask-restful-api/issues
* pip: https://pip.pypa.io/en/stable/quickstart/



